==> knative-model-4.12.0-sources.jar: annotations/io/fabric8/knative/eventing/contrib/gitlab/v1alpha1/GitLabBindingListBuilder.java <==
package io.fabric8.knative.eventing.contrib.gitlab.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class GitLabBindingListBuilder extends GitLabBindingListFluentImpl<GitLabBindingListBuilder> implements VisitableBuilder<GitLabBindingList,GitLabBindingListBuilder> {

    GitLabBindingListFluent<?> fluent;
    Boolean validationEnabled;

    public GitLabBindingListBuilder() { 
        this(true);
    }


    public GitLabBindingListBuilder(Boolean validationEnabled) { 
        this(new GitLabBindingList(), validationEnabled);
    }


    public GitLabBindingListBuilder(GitLabBindingListFluent<?> fluent) { 
        this(fluent, true);
    }


    public GitLabBindingListBuilder(GitLabBindingListFluent<?> fluent,Boolean validationEnabled) { 
        this(fluent, new GitLabBindingList(), validationEnabled);
    }


    public GitLabBindingListBuilder(GitLabBindingListFluent<?> fluent,GitLabBindingList instance) { 
        this(fluent, instance, true);
    }


    public GitLabBindingListBuilder(GitLabBindingListFluent<?> fluent,GitLabBindingList instance,Boolean validationEnabled) { 
        this.fluent = fluent; 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withItems(instance.getItems()); 
        fluent.withKind(instance.getKind()); 
        fluent.withMetadata(instance.getMetadata()); 
        this.validationEnabled = validationEnabled; 
    }


    public GitLabBindingListBuilder(GitLabBindingList instance) { 
        this(instance,true);
    }


    public GitLabBindingListBuilder(GitLabBindingList instance,Boolean validationEnabled) { 
        this.fluent = this; 
        this.withApiVersion(instance.getApiVersion()); 
        this.withItems(instance.getItems()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
        this.validationEnabled = validationEnabled; 
    }


    public GitLabBindingList build() {
        GitLabBindingList buildable = new GitLabBindingList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        GitLabBindingListBuilder that = (GitLabBindingListBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> knative-model-5.1.1-sources.jar: annotations/io/fabric8/knative/eventing/contrib/gitlab/v1alpha1/GitLabBindingListBuilder.java <==
package io.fabric8.knative.eventing.contrib.gitlab.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class GitLabBindingListBuilder extends GitLabBindingListFluentImpl<GitLabBindingListBuilder> implements VisitableBuilder<GitLabBindingList,GitLabBindingListBuilder> {

    GitLabBindingListFluent<?> fluent;
    Boolean validationEnabled;

    public GitLabBindingListBuilder() {
        this(true);
    }

    public GitLabBindingListBuilder(Boolean validationEnabled) {
        this(new GitLabBindingList(), validationEnabled);
    }

    public GitLabBindingListBuilder(GitLabBindingListFluent<?> fluent) {
        this(fluent, true);
    }

    public GitLabBindingListBuilder(GitLabBindingListFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new GitLabBindingList(), validationEnabled);
    }

    public GitLabBindingListBuilder(GitLabBindingListFluent<?> fluent,GitLabBindingList instance) {
        this(fluent, instance, true);
    }

    public GitLabBindingListBuilder(GitLabBindingListFluent<?> fluent,GitLabBindingList instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withItems(instance.getItems()); 
        fluent.withKind(instance.getKind()); 
        fluent.withMetadata(instance.getMetadata()); 
        this.validationEnabled = validationEnabled; 
    }

    public GitLabBindingListBuilder(GitLabBindingList instance) {
        this(instance,true);
    }

    public GitLabBindingListBuilder(GitLabBindingList instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withApiVersion(instance.getApiVersion()); 
        this.withItems(instance.getItems()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.EditableGitLabBindingList build() {
        EditableGitLabBindingList buildable = new EditableGitLabBindingList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        GitLabBindingListBuilder that = (GitLabBindingListBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
